@@ -4,26 +4,26 @@ use Evo ':Comp';
 
 use constant DEFAULT => Evo::Loop::Comp::new();
 
-sub start : Export(loop_start) { realm_lord(DEFAULT)->start(@_) }
+sub start : Export(loop_start) { DEFAULT->realm_lord->start(@_) }
 
-sub timer : Export(loop_timer) { realm_lord(DEFAULT)->timer(@_); }
+sub timer : Export(loop_timer) { DEFAULT->realm_lord->timer(@_); }
 
 sub timer_remove : Export(loop_timer_remove) {
-  realm_lord(DEFAULT)->timer_remove(@_);
+  DEFAULT->realm_lord->timer_remove(@_);
 }
 
 
-sub handle : Export(loop_handle)             { realm_lord(DEFAULT)->handle(@_) }
-sub handle_catch : Export(loop_handle_catch) { realm_lord(DEFAULT)->handle_catch(@_) }
+sub handle : Export(loop_handle)             { DEFAULT->realm_lord->handle(@_) }
+sub handle_catch : Export(loop_handle_catch) { DEFAULT->realm_lord->handle_catch(@_) }
 
 sub handle_remove : Export(loop_handle_remove) {
-  realm_lord(DEFAULT)->handle_remove(@_);
+  DEFAULT->realm_lord->handle_remove(@_);
 }
 
 
-sub postpone : prototype(&) : Export(loop_postpone) { realm_lord(DEFAULT)->postpone(@_) }
+sub postpone : prototype(&) : Export(loop_postpone) { DEFAULT->realm_lord->postpone(@_) }
 
-sub zone : Export(loop_zone) { realm_lord(DEFAULT)->zone(@_) }
+sub zone : Export(loop_zone) { DEFAULT->realm_lord->zone(@_) }
 
 1;
 
@@ -39,7 +39,7 @@ Evo::Loop
 
 =head1 VERSION
 
-version 0.0182
+version 0.0183
 
 =head1 AUTHOR
 
