@@ -1,5 +1,5 @@
 package Evo::Loop::Comp;
-use Evo '-Comp *', '-Lib steady_time', '-Export *';
+use Evo '-Comp *', '-Lib steady_time', '-Export *; -Realm *';
 use List::Util 'first';
 use Time::HiRes 'usleep';
 
@@ -58,7 +58,7 @@ Evo::Loop::Comp
 
 =head1 VERSION
 
-version 0.0182
+version 0.0183
 
 =head1 AUTHOR
 
